// qxgeditAbout.h
//
/****************************************************************************
   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*****************************************************************************/

#ifndef __qxgeditAbout_h
#define __qxgeditAbout_h

#include "config.h"

#define QXGEDIT_TITLE       PROJECT_TITLE

#define QXGEDIT_SUBTITLE    PROJECT_DESCRIPTION
#define QXGEDIT_WEBSITE     PROJECT_HOMEPAGE_URL

#define QXGEDIT_COPYRIGHT   PROJECT_COPYRIGHT
#define QXGEDIT_DOMAIN      PROJECT_DOMAIN

#endif  // __qxgeditAbout_h

// end of qxgeditAbout.h

